@@ -30,10 +30,26 @@ class SinkNode(Node):
         self,
         start_ts: Optional[int] = None,
         end_ts: Optional[int] = None,
+        seek_to_latest: bool = False,
         profile: Optional[bool] = False,
     ) -> None:
+        assert (
+            self.consumer is not None
+        ), "Cannot consume messages. Consumer not initialized"
+
+        if start_ts is not None and seek_to_latest:
+            raise RuntimeError(
+                "Cannot start processor. start_ts and seek_to_latest cannot be used together"
+            )
+
         if start_ts is not None:
-            pass
+            partitions = self.consumer.partitions_for_topic(self.source_topic)
+            offsets = self.consumer.offsets_for_times(
+                {partition: start_ts for partition in partitions}
+            )
+            for parition, offset_and_ts in offsets.items():
+                self.consumer.seek(parition, offset_and_ts.offset)
+
         profiler = ProtoTimer(disable=not profile)
 
         async for record in self.consumer():
