@@ -31,24 +31,26 @@ class SourceNode(Node):
     async def _process(
         self,
         profile: bool = False,
-    ) -> Optional[NewMessage]:
-        output_msg = await self.process()
-        if output_msg is not None and profile:
-            trace = profiler.init_trace()
-            profiler.touch_trace(trace, self.publish_topic)
-            output_msg.trace = trace
-        return output_msg
+    ) -> List[NewMessage]:
+        output_msgs = await self.process()
+        if profile:
+            for output_msg in output_msgs:
+                trace = output_msg.trace
+                if trace is None:
+                    trace = profiler.init_trace()
+                profiler.touch_trace(trace, self.publish_topic)
+                output_msg.trace = trace
+        return output_msgs
 
-    async def process(self) -> Optional[NewMessage]:
+    async def process(self) -> List[NewMessage]:
         raise NotImplementedError
 
     async def run(
         self,
-        start_ts: Optional[int] = None,
-        end_ts: Optional[int] = None,
         profile: Optional[bool] = False,
     ) -> None:
+
         while True:
-            output_msg = await self._process()
-            if output_msg is not None:
-                await self._publish(output_msg)
+            output_msgs = await self._process()
+            for output_msg in output_msgs:
+                await self._publish(output_msg)
\ No newline at end of file
